@@ -27,7 +27,6 @@ func init() {
 			{"_registry", 0, 0, i._registry, nil},
 			{"_tovalue", 1, 1, i._toValue, nil},
 			{"_decode", 2, 2, i._decode, nil},
-			{"_is_decode_value", 0, 0, i._isDecodeValue, nil},
 		}
 	})
 }
@@ -158,11 +157,11 @@ func (i *Interp) _decode(c interface{}, a []interface{}) interface{} {
 			evalProgress := func(c interface{}) {
 				// {approx_read_bytes: 123, total_size: 123} | opts.Progress
 				_, _ = i.EvalFuncValues(
-					i.evalContext.ctx,
+					i.evalInstance.ctx,
 					c,
 					opts.Progress,
 					nil,
-					EvalOpts{output: ioextra.DiscardCtxWriter{Ctx: i.evalContext.ctx}},
+					EvalOpts{output: ioextra.DiscardCtxWriter{Ctx: i.evalInstance.ctx}},
 				)
 			}
 			lastProgress := time.Now()
@@ -202,7 +201,7 @@ func (i *Interp) _decode(c interface{}, a []interface{}) interface{} {
 		return err
 	}
 
-	dv, _, err := decode.Decode(i.evalContext.ctx, bv.br, decodeFormat,
+	dv, _, err := decode.Decode(i.evalInstance.ctx, bv.br, decodeFormat,
 		decode.Options{
 			IsRoot:        true,
 			FillGaps:      true,
@@ -229,11 +228,6 @@ func (i *Interp) _decode(c interface{}, a []interface{}) interface{} {
 	return makeDecodeValue(dv)
 }
 
-func (i *Interp) _isDecodeValue(c interface{}, a []interface{}) interface{} {
-	_, ok := c.(DecodeValue)
-	return ok
-}
-
 func valueKey(name string, a, b func(name string) interface{}) interface{} {
 	if strings.HasPrefix(name, "_") {
 		return a(name)
