@@ -36,15 +36,17 @@ import (
 
 //go:embed interp.jq
 //go:embed internal.jq
+//go:embed eval.jq
 //go:embed options.jq
+//go:embed ansi.jq
 //go:embed binary.jq
 //go:embed decode.jq
-//go:embed match.jq
 //go:embed funcs.jq
 //go:embed grep.jq
 //go:embed args.jq
 //go:embed query.jq
 //go:embed repl.jq
+//go:embed help.jq
 //go:embed formats.jq
 var builtinFS embed.FS
 
@@ -56,7 +58,7 @@ func init() {
 	functionRegisterFns = append(functionRegisterFns, func(i *Interp) []Function {
 		return []Function{
 			{"_readline", 0, 1, nil, i._readline},
-			{"eval", 1, 2, nil, i.eval},
+			{"_eval", 1, 2, nil, i._eval},
 			{"_stdin", 0, 1, nil, i.makeStdioFn("stdin", i.os.Stdin())},
 			{"_stdout", 0, 0, nil, i.makeStdioFn("stdout", i.os.Stdout())},
 			{"_stderr", 0, 0, nil, i.makeStdioFn("stderr", i.os.Stderr())},
@@ -324,10 +326,11 @@ const (
 	CompletionMode
 )
 
-type evalContext struct {
+type evalInstance struct {
 	ctx          context.Context
 	output       io.Writer
 	isCompleting bool
+	includeSeen  map[string]struct{}
 }
 
 type Interp struct {
@@ -339,8 +342,8 @@ type Interp struct {
 	// global state, is ref as Interp is cloned per eval
 	state *interface{}
 
-	// new for each run, other values are copied by value
-	evalContext evalContext
+	// new for each eval, other values are copied by value
+	evalInstance evalInstance
 }
 
 func New(os OS, registry *registry.Registry) (*Interp, error) {
@@ -424,7 +427,7 @@ func (i *Interp) Main(ctx context.Context, output Output, versionStr string) err
 }
 
 func (i *Interp) _readline(c interface{}, a []interface{}) gojq.Iter {
-	if i.evalContext.isCompleting {
+	if i.evalInstance.isCompleting {
 		return gojq.NewIter()
 	}
 
@@ -441,10 +444,10 @@ func (i *Interp) _readline(c interface{}, a []interface{}) gojq.Iter {
 	expr, err := i.os.Readline(ReadlineOpts{
 		Prompt: opts.Promopt,
 		CompleteFn: func(line string, pos int) (newLine []string, shared int) {
-			completeCtx := i.evalContext.ctx
+			completeCtx := i.evalInstance.ctx
 			if opts.Timeout > 0 {
 				var completeCtxCancelFn context.CancelFunc
-				completeCtx, completeCtxCancelFn = context.WithTimeout(i.evalContext.ctx, time.Duration(opts.Timeout*float64(time.Second)))
+				completeCtx, completeCtxCancelFn = context.WithTimeout(i.evalInstance.ctx, time.Duration(opts.Timeout*float64(time.Second)))
 				defer completeCtxCancelFn()
 			}
 
@@ -506,7 +509,7 @@ func (i *Interp) _readline(c interface{}, a []interface{}) gojq.Iter {
 	return gojq.NewIter(expr)
 }
 
-func (i *Interp) eval(c interface{}, a []interface{}) gojq.Iter {
+func (i *Interp) _eval(c interface{}, a []interface{}) gojq.Iter {
 	var err error
 	expr, err := toString(a[0])
 	if err != nil {
@@ -520,9 +523,9 @@ func (i *Interp) eval(c interface{}, a []interface{}) gojq.Iter {
 		}
 	}
 
-	iter, err := i.Eval(i.evalContext.ctx, c, expr, EvalOpts{
+	iter, err := i.Eval(i.evalInstance.ctx, c, expr, EvalOpts{
 		filename: filenameHint,
-		output:   i.evalContext.output,
+		output:   i.evalInstance.output,
 	})
 	if err != nil {
 		return gojq.NewIter(err)
@@ -546,7 +549,7 @@ func (i *Interp) _extType(c interface{}, a []interface{}) interface{} {
 	if v, ok := c.(Value); ok {
 		return v.ExtType()
 	}
-	return nil
+	return gojqextra.Typeof(c)
 }
 
 func (i *Interp) makeStateFn(state *interface{}) func(c interface{}, a []interface{}) interface{} {
@@ -562,7 +565,7 @@ func (i *Interp) makeStdioFn(name string, t Terminal) func(c interface{}, a []in
 	return func(c interface{}, a []interface{}) gojq.Iter {
 		switch {
 		case len(a) == 1:
-			if i.evalContext.isCompleting {
+			if i.evalInstance.isCompleting {
 				return gojq.NewIter("")
 			}
 
@@ -596,7 +599,7 @@ func (i *Interp) makeStdioFn(name string, t Terminal) func(c interface{}, a []in
 				"height":      h,
 			})
 		default:
-			if i.evalContext.isCompleting {
+			if i.evalInstance.isCompleting {
 				return gojq.NewIter()
 			}
 
@@ -629,7 +632,7 @@ func (i *Interp) _display(c interface{}, a []interface{}) gojq.Iter {
 
 	switch v := c.(type) {
 	case Display:
-		if err := v.Display(i.evalContext.output, opts); err != nil {
+		if err := v.Display(i.evalInstance.output, opts); err != nil {
 			return gojq.NewIter(err)
 		}
 		return gojq.NewIter()
@@ -650,7 +653,7 @@ func (i *Interp) _printColorJSON(c interface{}, a []interface{}) gojq.Iter {
 	if err != nil {
 		return gojq.NewIter(err)
 	}
-	if err := cj.Marshal(c, i.evalContext.output); err != nil {
+	if err := cj.Marshal(c, i.evalInstance.output); err != nil {
 		return gojq.NewIter(err)
 	}
 
@@ -658,7 +661,7 @@ func (i *Interp) _printColorJSON(c interface{}, a []interface{}) gojq.Iter {
 }
 
 func (i *Interp) _isCompleting(c interface{}, a []interface{}) interface{} {
-	return i.evalContext.isCompleting
+	return i.evalInstance.isCompleting
 }
 
 type pathResolver struct {
@@ -735,11 +738,13 @@ func (i *Interp) Eval(ctx context.Context, c interface{}, expr string, opts Eval
 	// make copy of interp and give it its own eval context
 	ci := *i
 	ni := &ci
-	ni.evalContext = evalContext{}
+	ni.evalInstance = evalInstance{
+		includeSeen: map[string]struct{}{},
+	}
 
 	var variableNames []string
 	var variableValues []interface{}
-	for k, v := range i.variables() {
+	for k, v := range i.slurps() {
 		variableNames = append(variableNames, "$"+k)
 		variableValues = append(variableValues, v)
 	}
@@ -785,6 +790,13 @@ func (i *Interp) Eval(ctx context.Context, c interface{}, expr string, opts Eval
 				return nil, err
 			}
 
+			// skip if this eval instance has already included the file
+			if _, ok := ni.evalInstance.includeSeen[filename]; ok {
+				return &gojq.Query{Term: &gojq.Term{Type: gojq.TermTypeIdentity}}, nil
+			}
+			ni.evalInstance.includeSeen[filename] = struct{}{}
+
+			// return cached version if file has already been parsed
 			if q, ok := ni.includeCache[filename]; ok {
 				return q, nil
 			}
@@ -895,10 +907,10 @@ func (i *Interp) Eval(ctx context.Context, c interface{}, expr string, opts Eval
 	}
 
 	runCtx, runCtxCancelFn := i.interruptStack.Push(ctx)
-	ni.evalContext.ctx = runCtx
-	ni.evalContext.output = ioextra.CtxWriter{Writer: output, Ctx: runCtx}
-	// inherit or set
-	ni.evalContext.isCompleting = i.evalContext.isCompleting || opts.isCompleting
+	ni.evalInstance.ctx = runCtx
+	ni.evalInstance.output = ioextra.CtxWriter{Writer: output, Ctx: runCtx}
+	// inherit or maybe set
+	ni.evalInstance.isCompleting = i.evalInstance.isCompleting || opts.isCompleting
 	iter := gc.RunWithContext(runCtx, c, variableValues...)
 
 	iterWrapper := iterFn(func() (interface{}, bool) {
@@ -906,6 +918,8 @@ func (i *Interp) Eval(ctx context.Context, c interface{}, expr string, opts Eval
 		// gojq ctx cancel will not return ok=false, just cancelled error
 		if !ok {
 			runCtxCancelFn()
+		} else if _, ok := v.(error); ok {
+			runCtxCancelFn()
 		}
 		return v, ok
 	})
@@ -956,24 +970,27 @@ func (i *Interp) EvalFuncValues(ctx context.Context, c interface{}, name string,
 }
 
 type Options struct {
-	Depth          int    `mapstructure:"depth"`
-	ArrayTruncate  int    `mapstructure:"array_truncate"`
-	Verbose        bool   `mapstructure:"verbose"`
-	DecodeProgress bool   `mapstructure:"decode_progress"`
-	Color          bool   `mapstructure:"color"`
-	Colors         string `mapstructure:"colors"`
-	ByteColors     string `mapstructure:"byte_colors"`
-	Unicode        bool   `mapstructure:"unicode"`
-	RawOutput      bool   `mapstructure:"raw_output"`
-	REPL           bool   `mapstructure:"repl"`
-	RawString      bool   `mapstructure:"raw_string"`
-	JoinString     string `mapstructure:"join_string"`
-	Compact        bool   `mapstructure:"compact"`
-	BitsFormat     string `mapstructure:"bits_format"`
-	LineBytes      int    `mapstructure:"line_bytes"`
-	DisplayBytes   int    `mapstructure:"display_bytes"`
-	AddrBase       int    `mapstructure:"addrbase"`
-	SizeBase       int    `mapstructure:"sizebase"`
+	Depth          int               `mapstructure:"depth"`
+	ArrayTruncate  int               `mapstructure:"array_truncate"`
+	Verbose        bool              `mapstructure:"verbose"`
+	DecodeProgress bool              `mapstructure:"decode_progress"`
+	Color          bool              `mapstructure:"color"`
+	Colors         map[string]string `mapstructure:"colors"`
+	ByteColors     []struct {
+		Ranges [][2]int `mapstructure:"ranges"`
+		Value  string   `mapstructure:"value"`
+	} `mapstructure:"byte_colors"`
+	Unicode      bool   `mapstructure:"unicode"`
+	RawOutput    bool   `mapstructure:"raw_output"`
+	REPL         bool   `mapstructure:"repl"`
+	RawString    bool   `mapstructure:"raw_string"`
+	JoinString   string `mapstructure:"join_string"`
+	Compact      bool   `mapstructure:"compact"`
+	BitsFormat   string `mapstructure:"bits_format"`
+	LineBytes    int    `mapstructure:"line_bytes"`
+	DisplayBytes int    `mapstructure:"display_bytes"`
+	AddrBase     int    `mapstructure:"addrbase"`
+	SizeBase     int    `mapstructure:"sizebase"`
 
 	Decorator    Decorator
 	BitsFormatFn func(br bitio.ReaderAtSeeker) (interface{}, error)
@@ -1064,9 +1081,9 @@ func (i *Interp) includePaths() []string {
 	return paths
 }
 
-func (i *Interp) variables() map[string]interface{} {
-	variablesAny, _ := i.lookupState("variables").(map[string]interface{})
-	return variablesAny
+func (i *Interp) slurps() map[string]interface{} {
+	slurpsAny, _ := i.lookupState("slurps").(map[string]interface{})
+	return slurpsAny
 }
 
 func (i *Interp) Options(v interface{}) Options {
